==> mkdocs-dracula-theme-1.0.5.tar.gz: mkdocs-dracula-theme-1.0.5/README.md <==
# Dracula for [Mkdocs](https://www.mkdocs.org/)

> A dark theme for [Mkdocs](https://www.mkdocs.org/).

![Screenshot](https://raw.githubusercontent.com/dracula/mkdocs/main/screenshot.png)

## Install

### Installation MkDocs

To install MkDocs, run the following command from the command line:

```bash
pip install mkdocs
```

### Installation theme

Install the theme using PIP:

```bash
pip install mkdocs-dracula-theme
```

### Activating theme

After the theme is installed, edit your `mkdocs.yml` file and set the theme name to `dracula`:

```yml
theme:
    name: dracula
```

All instructions can be found at [draculatheme.com/mkdocs](https://draculatheme.com/mkdocs).

## Team

This theme is maintained by the following person(s) and a bunch of [awesome contributors](https://github.com/dracula/foobar/graphs/contributors).

| [![Fernando Celmer](https://github.com/FernandoCelmer.png?size=100)](https://github.com/FernandoCelmer) |
| ---------------------------------------------------------------------------------------- |
| [Fernando Celmer](https://github.com/FernandoCelmer)                                          |

## Community

- [Twitter](https://twitter.com/draculatheme) - Best for getting updates about themes and new stuff.
- [GitHub](https://github.com/dracula/dracula-theme/discussions) - Best for asking questions and discussing issues.
- [Discord](https://draculatheme.com/discord-invite) - Best for hanging out with the community.

## Commit Style

- ⚙️ FEATURE
- 📝 PEP8
- 📌 ISSUE
- 🪲 BUG
- 📘 DOCS
- 📦 PyPI
- ❤️️ TEST
- ⬆️ CI/CD
- ⚠️ SECURITY

## License

[MIT License](./LICENSE)

==> mkdocs-dracula-theme-1.0.6.tar.gz: mkdocs-dracula-theme-1.0.6/README.md <==
# Dracula for [Mkdocs](https://www.mkdocs.org/)

> A dark theme for [Mkdocs](https://www.mkdocs.org/).

![Screenshot](https://raw.githubusercontent.com/dracula/mkdocs/main/screenshot.png)

## Install

### Installation MkDocs

To install MkDocs, run the following command from the command line:

```bash
pip install mkdocs
```

### Installation theme

Install the theme using PIP:

```bash
pip install mkdocs-dracula-theme
```

### Activating theme

After the theme is installed, edit your `mkdocs.yml` file and set the theme name to `dracula`:

```yml
theme:
    name: dracula
```

All instructions can be found at [draculatheme.com/mkdocs](https://draculatheme.com/mkdocs).

## Team

This theme is maintained by the following person(s) and a bunch of [awesome contributors](https://github.com/dracula/mkdocs/graphs/contributors).

| [![Fernando Celmer](https://github.com/FernandoCelmer.png?size=100)](https://github.com/FernandoCelmer) |                                               |
| ------------------------------------------------------------------------------------------------------- | --------------------------------------------- |
| [Fernando Celmer](https://github.com/FernandoCelmer)                                                    | [Lautaro Linquimán](https://github.com/Ymil)  |

## Community

- [Twitter](https://twitter.com/draculatheme) - Best for getting updates about themes and new stuff.
- [GitHub](https://github.com/dracula/dracula-theme/discussions) - Best for asking questions and discussing issues.
- [Discord](https://draculatheme.com/discord-invite) - Best for hanging out with the community.

## Commit Style

- ⚙️ FEATURE
- 📝 PEP8
- 📌 ISSUE
- 🪲 BUG
- 📘 DOCS
- 📦 PyPI
- ❤️️ TEST
- ⬆️ CI/CD
- ⚠️ SECURITY

## License

[MIT License](./LICENSE)
